@@ -132,9 +132,9 @@ class RinnaiWaterHeater(object):
         )
 
         if r.status_code == 200:
-            loggin.info("Successfully sent initAuth")
+            logging.info("Successfully sent initAuth")
             result = r.json()
-            payload = process_challenge(result['ChallengeParameters'])
+            payload = self.process_challenge(result['ChallengeParameters'])
 
             r = requests.post(
                 baseAuthUrl,
@@ -241,7 +241,16 @@ class RinnaiWaterHeater(object):
 
         if r.status_code == 200:
             result = r.json()
-            return result['data']['getUserByEmail']['items']['devices']['items']
+            data = result.get('data')
+            if data:
+                getUserByEmail = data.get('getUserByEmail')
+                if getUserByEmail:
+                    items = getUserByEmail.get('items')
+                    if items:
+                        devices = items.get('devices')
+                        if devices:
+                            device_items = devices.get('items')
+            return device_items
         else:
             r.raise_for_status()
 
@@ -281,7 +290,7 @@ class RinnaiWaterHeater(object):
         timestamp = re.sub(r" 0(\d) ", r" \1 ",
                                datetime.datetime.utcnow().strftime("%a %b %d %H:%M:%S UTC %Y"))
 
-        hkdf = get_password_authentication_key(user_id_for_srp, self.password, hex_to_long(srp_b_hex), salt_hex)
+        hkdf = self.get_password_authentication_key(user_id_for_srp, self.password, hex_to_long(srp_b_hex), salt_hex)
         secret_block_bytes = base64.standard_b64decode(secret_block_b64)
         msg = bytearray(self.pool_id.split('_')[1], 'utf-8') + bytearray(user_id_for_srp, 'utf-8') + \
                   bytearray(secret_block_bytes) + bytearray(timestamp, 'utf-8')
